@@ -156,7 +156,8 @@ class Feature():
 		for left,right in self:
 			#left,right = map(int, [ item.replace('<','').replace('>','') for item in self.pair ] )
 			for i in range(left,right+1):
-				yield i
+				if i <= self.locus.length():
+					yield i
 
 	def codon_locations(self):
 		assert self.type == 'CDS'
@@ -215,9 +216,10 @@ class Feature():
 		if not self.strand > 0:
 			outfile.write(')')
 		outfile.write('\n')
-		for key,value in self.tags.items():
-			for line in textwrap.wrap( '/' + str(key) + '=' + str(value) , 58):
-				outfile.write('                     ')
-				outfile.write(line)
-				outfile.write('\n')
+		for key,values in self.tags.items():
+			for value in values:
+				for line in textwrap.wrap( '/' + str(key) + '=' + str(value) , 58):
+					outfile.write('                     ')
+					outfile.write(line)
+					outfile.write('\n')
 
